Read like plate, Playt with fun
Playt is a game library for the terminal.
It functions as a basic wrapper over pancurses by providing utility functions and extending types.
It also helps you manage the state of your game by separating it into Stages
and putting global data in a Game instance.